aboutsummaryrefslogtreecommitdiffstats
path: root/lib/soapy/soapy_source_c.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/soapy/soapy_source_c.h')
-rw-r--r--lib/soapy/soapy_source_c.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/soapy/soapy_source_c.h b/lib/soapy/soapy_source_c.h
index b4db1ce..7ae6322 100644
--- a/lib/soapy/soapy_source_c.h
+++ b/lib/soapy/soapy_source_c.h
@@ -36,7 +36,7 @@ namespace SoapySDR
}
/*
* We use boost::shared_ptr's instead of raw pointers for all access
* to gr_blocks (and many other data structures). The shared_ptr gets
* us transparent reference counting, which greatly simplifies storage
* management issues. This is especially helpful in our hybrid
@@ -44,9 +44,9 @@ namespace SoapySDR
*
* See http://www.boost.org/libs/smart_ptr/smart_ptr.htm
*
* As a convention, the _sptr suffix indicates a boost::shared_ptr
*/
-typedef boost::shared_ptr<soapy_source_c> soapy_source_c_sptr;
+typedef std::shared_ptr<soapy_source_c> soapy_source_c_sptr;
/*!
* \brief Return a shared_ptr to a new instance of soapy_source_c.
@@ -36,7 +36,7 @@ namespace SoapySDR
}
/*
- * We use boost::shared_ptr's instead of raw pointers for all access
+ * We use std::shared_ptr's instead of raw pointers for all access
* to gr_blocks (and many other data structures). The shared_ptr gets
* us transparent reference counting, which greatly simplifies storage
@@ -44,9 +44,9 @@ namespace SoapySDR
* See http://www.boost.org/libs/smart_ptr/smart_ptr.htm
*
- * As a convention, the _sptr suffix indicates a boost::shared_ptr
+ * As a convention, the _sptr suffix indicates a std::shared_ptr
*/